aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/typing.h
diff options
context:
space:
mode:
authorAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
committerAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
commit09eb39236666e81d5da014acea011dcd74d0999b (patch)
tree52876d96be71be1a39d5d935c1295a51995e8949 /lib/csapi/typing.h
parentf1788ee27f33e9339334e0d79bde9a27d9ce2e44 (diff)
parenta4e78956f105875625b572d8b98459ffa86fafe5 (diff)
downloadlibquotient-09eb39236666e81d5da014acea011dcd74d0999b.tar.gz
libquotient-09eb39236666e81d5da014acea011dcd74d0999b.zip
Update upstream source from tag 'upstream/0.6.4'
Update to upstream version '0.6.4' with Debian dir aa8705fd74743e79c043bc9e3e425d5064404cfe
Diffstat (limited to 'lib/csapi/typing.h')
-rw-r--r--lib/csapi/typing.h56
1 files changed, 29 insertions, 27 deletions
diff --git a/lib/csapi/typing.h b/lib/csapi/typing.h
index c6201440..2c953949 100644
--- a/lib/csapi/typing.h
+++ b/lib/csapi/typing.h
@@ -6,32 +6,34 @@
#include "jobs/basejob.h"
-#include "converters.h"
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Informs the server that the user has started or stopped typing.
+ *
+ * This tells the server that the user is typing for the next N
+ * milliseconds where N is the value specified in the ``timeout`` key.
+ * Alternatively, if ``typing`` is ``false``, it tells the server that the
+ * user has stopped typing.
+ */
+class SetTypingJob : public BaseJob {
+public:
+ /*! \brief Informs the server that the user has started or stopped typing.
+ *
+ * \param userId
+ * The user who has started to type.
+ *
+ * \param roomId
+ * The room in which the user is typing.
+ *
+ * \param typing
+ * Whether the user is typing or not. If ``false``, the ``timeout``
+ * key can be omitted.
+ *
+ * \param timeout
+ * The length of time in milliseconds to mark this user as typing.
+ */
+ explicit SetTypingJob(const QString& userId, const QString& roomId,
+ bool typing, Omittable<int> timeout = none);
+};
- /// Informs the server that the user has started or stopped typing.
- ///
- /// This tells the server that the user is typing for the next N
- /// milliseconds where N is the value specified in the ``timeout`` key.
- /// Alternatively, if ``typing`` is ``false``, it tells the server that the
- /// user has stopped typing.
- class SetTypingJob : public BaseJob
- {
- public:
- /*! Informs the server that the user has started or stopped typing.
- * \param userId
- * The user who has started to type.
- * \param roomId
- * The room in which the user is typing.
- * \param typing
- * Whether the user is typing or not. If ``false``, the ``timeout``
- * key can be omitted.
- * \param timeout
- * The length of time in milliseconds to mark this user as typing.
- */
- explicit SetTypingJob(const QString& userId, const QString& roomId, bool typing, Omittable<int> timeout = none);
- };
-} // namespace QMatrixClient
+} // namespace Quotient